==> haskell-record-hasfield-1.0-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-record-hasfield.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 record-hasfield
version:              1.0
visibility:           public
id:                   record-hasfield-1.0-DcbNZv0cAfk5VzIQxsym4J
key:                  record-hasfield-1.0-DcbNZv0cAfk5VzIQxsym4J
license:              BSD-3-Clause
copyright:            Adam Gundry and Neil Mitchell 2018-2019
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:             https://github.com/ndmitchell/record-hasfield#readme
synopsis:             A version of GHC.Records as available in future GHCs.
description:
    This package provides a version of "GHC.Records" as it will be after the implementation of
    <https://github.com/ghc-proposals/ghc-proposals/blob/master/proposals/0042-record-set-field.rst GHC proposal #42>,
    plus some helper functions over it.

category:             Development
abi:                  9205c6915ae31b7dfd03353adc05e689
exposed:              True
exposed-modules:      GHC.Records.Compat GHC.Records.Extra
import-dirs:          /usr/lib/ghc-8.10.2/site-local/record-hasfield-1.0
library-dirs:         /usr/lib/ghc-8.10.2/site-local/record-hasfield-1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/record-hasfield-1.0
hs-libraries:         HSrecord-hasfield-1.0-DcbNZv0cAfk5VzIQxsym4J
depends:              base-4.14.1.0
haddock-interfaces:
    /usr/share/doc/haskell-record-hasfield/html/record-hasfield.haddock

haddock-html:         /usr/share/doc/haskell-record-hasfield/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-record-hasfield-1.0.1-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-record-hasfield.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 record-hasfield
version:              1.0.1
visibility:           public
id:                   record-hasfield-1.0.1-DxdPlAQxGxE6T8GIJIe3RM
key:                  record-hasfield-1.0.1-DxdPlAQxGxE6T8GIJIe3RM
license:              BSD-3-Clause
copyright:            Adam Gundry and Neil Mitchell 2018-2024
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:             https://github.com/ndmitchell/record-hasfield#readme
synopsis:             A version of GHC.Records as available in future GHCs.
description:
    This package provides a version of "GHC.Records" as it will be after the implementation of
    <https://github.com/ghc-proposals/ghc-proposals/blob/master/proposals/0042-record-set-field.rst GHC proposal #42>,
    plus some helper functions over it.

category:             Development
abi:                  78257587118a7128718978f2a7183b54
exposed:              True
exposed-modules:      GHC.Records.Compat GHC.Records.Extra
import-dirs:          /usr/lib/ghc-9.0.2/site-local/record-hasfield-1.0.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/record-hasfield-1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-record-hasfield
hs-libraries:         HSrecord-hasfield-1.0.1-DxdPlAQxGxE6T8GIJIe3RM
depends:              base-4.15.1.0
haddock-interfaces:
    /usr/share/doc/haskell-record-hasfield/html/record-hasfield.haddock

haddock-html:         /usr/share/doc/haskell-record-hasfield/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
